stm32-metapac

Crates

git

Versions

stm32u5a5qj

Flavors

Ocolr

Struct Ocolr 

#[repr(transparent)]
pub struct Ocolr(pub u32);
DMA2D output color register

Tuple Fields

0: u32

Implementations



impl Ocolr

pub const fn color(&self) -> u32

Color. Color in the format specified by color mode in OPFCCR (16, 24 or 32 bits). These bits can only be written when data transfers are disabled. Once the transfer has started, they are read-only.

pub const fn set_color(&mut self, val: u32)

Color. Color in the format specified by color mode in OPFCCR (16, 24 or 32 bits). These bits can only be written when data transfers are disabled. Once the transfer has started, they are read-only.